==> geometa_0.6-3.tar.gz: geometa/R/ISOReferenceIdentifier.R <==
#' ISOReferenceIdentifier
#'
#' @docType class
#' @importFrom R6 R6Class
#' @export
#' @keywords ISO reference identifier
#' @return Object of \code{\link{R6Class}} for modelling an ISO ReferenceIdentifier
#' @format \code{\link{R6Class}} object.
#'
#' @field codeSpace [\code{\link{character}}] codespace
#' @field version [\code{\link{character}}] version
#'
#' @section Methods:
#' \describe{
#'  \item{\code{new(xml, code, codeSpace)}}{
#'    This method is used to instantiate an \code{\link{ISOReferenceIdentifier}}
#'  }
#'  \item{\code{setCodeSpace(codeSpace)}}{
#'    Sets a codeSpace
#'  }
#'  \item{\code{setVersion(version)}}{
#'    Sets a version
#'  }
#' }
#' 
#' @examples 
#'   md <- ISOReferenceIdentifier$new(code = "4326", codeSpace = "EPSG")
#'   xml <- md$encode()
#'   
#' @references 
#'   ISO 19115:2003 - Geographic information -- Metadata
#' 
#' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
#'
ISOReferenceIdentifier <- R6Class("ISOReferenceIdentifier",
   inherit = ISOIdentifier,
   private = list(
     xmlElement = "RS_Identifier",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
     #+ codeSpace [0..1]: character
     codeSpace = NULL,
     #+ version [0..1]: character
     version = NULL,
     initialize = function(xml = NULL, code, codeSpace = NULL){
       super$initialize(xml = xml, code = code)
       if(!is.null(codeSpace)) self$setCodeSpace(codeSpace)
     },
     
     #setCodeSpace
     setCodeSpace = function(codeSpace){
       self$codeSpace = codeSpace
     },
     
     #setVersion
     setVersion = function(version){
       self$version = version
     }
   )                        
)

==> geometa_0.8-0.tar.gz: geometa/R/ISOReferenceIdentifier.R <==
#' ISOReferenceIdentifier
#'
#' @docType class
#' @importFrom R6 R6Class
#' @export
#' @keywords ISO reference identifier
#' @return Object of \code{\link{R6Class}} for modelling an ISO ReferenceIdentifier
#' @format \code{\link{R6Class}} object.
#' 
#' @examples 
#'   md <- ISOReferenceIdentifier$new(code = "4326", codeSpace = "EPSG")
#'   xml <- md$encode()
#'   
#' @references 
#'   ISO 19115:2003 - Geographic information -- Metadata
#' 
#' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
#'
ISOReferenceIdentifier <- R6Class("ISOReferenceIdentifier",
   inherit = ISOIdentifier,
   private = list(
     xmlElement = "RS_Identifier",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
     #'@field codeSpace codeSpace [0..1]: character
     codeSpace = NULL,
     #'@field version version [0..1]: character
     version = NULL,
     
     #'@description Initializes object
     #'@param xml object of class \link{XMLInternalNode-class}
     #'@param code code
     #'@param codeSpace code space
     initialize = function(xml = NULL, code, codeSpace = NULL){
       super$initialize(xml = xml, code = code)
       if(!is.null(codeSpace)) self$setCodeSpace(codeSpace)
     },
     
     #'@description Set code space
     #'@param codeSpace code space
     setCodeSpace = function(codeSpace){
       self$codeSpace = codeSpace
     },
     
     #'@description Set version
     #'@param version version
     setVersion = function(version){
       self$version = version
     }
   )                        
)
